from LLMTests.extractMethods.prompt_generator import PromptGenerator
from LLMTests.unitTestGenerator.llm_client import LLMClient
from LLMTests.utils.logging_utils import LoggerSetup
from LLMTests.config import Config
from pathlib import Path

logger_setup = LoggerSetup(logger_name="TestExplainer")
logger = logger_setup.get_logger()

def generate_test_explanations(test_results, base_path: str = None, project_path: str = None):
    """
    Generate explanations for failed tests using the LLM.

    Args:
        test_results: List of test result dictionaries.
        base_path: Base path where the Maven project is set up
        project_path: Path to the original project source

    Returns:
        Dict containing explanations.
    """
    try:
        # Filter failed tests
        failed_tests = [result for result in test_results if not result.get('status')]

        if not failed_tests:
            return {}

        # Set up paths for Maven structure
        target_dir = Path('/home/coder/workspace/white-box-testing/testframeworkwhiteboxmodul/LLMTests/testExecution/javametrics')
        source_dir = target_dir / 'src' / 'main' / 'java'

        # Find Java source files
        java_files = list(source_dir.rglob('*.java'))
        if not java_files:
            logger.error("No Java source files found")
            return {}

        # Read source code from all Java files
        source_code = ""
        for java_file in java_files:
            with open(java_file, 'r') as f:
                source_code += f"\n// File: {java_file.name}\n"
                source_code += f.read()

        # Generate prompt
        prompt_generator = PromptGenerator()
        prompt = prompt_generator.create_explanation_prompt(failed_tests, source_code)

        # Send prompt to LLM
        config = Config()
        llm_client = LLMClient(config)
        explanation = llm_client.send_prompt(prompt)

        return {'explanation': explanation}

    except Exception as e:
        logger.error(f"Error generating test explanations: {str(e)}")
        return {}
