# test_result.py

from dataclasses import dataclass
from typing import List, Dict, Optional
from .test_failure import TestFailure

@dataclass
class TestResult:
    """Represents the complete results of a test execution."""
    test_name: str
    success: bool
    total_tests: int
    passed_tests: int
    execution_time: float
    failures: List[TestFailure]
    errors: List[str]
    stdout: str
    stderr: str
    source_code_context: Optional[Dict[str, str]] = None

    def to_dict(self) -> Dict:
        """Convert the test result to a dictionary format."""
        return {
            'test_name': self.test_name,
            'success': self.success,
            'total_tests': self.total_tests,
            'passed_tests': self.passed_tests,
            'failed_tests': self.total_tests - self.passed_tests,
            'execution_time': round(self.execution_time, 3),
            'failures': [f.__dict__ for f in self.failures],
            'errors': self.errors,
            'stdout': self.stdout,
            'stderr': self.stderr,
            'source_code_context': self.source_code_context
        }