import json
import logging
from pathlib import Path
from typing import Tuple

from LLMTests.utils.logging_utils import LoggerSetup

logger_setup = LoggerSetup(logger_name="TestCounter")
logger = logger_setup.get_logger()

def count_total_tests(test_path: Path) -> Tuple[int, int]:
    """
    Count total number of test files and individual tests in all JSON files.
    
    Args:
        test_path (Path): Path to the test files directory
        
    Returns:
        Tuple[int, int]: (number of test files, total number of individual tests)
    """
    total_files = 0
    total_tests = 0
    
    try:
        json_files = list(test_path.glob('*.json'))
        total_files = len(json_files)
        
        for test_file in json_files:
            try:
                with open(test_file, 'r') as f:
                    test_data = json.load(f)
                    
                # Count number of test methods in the test code
                test_code = test_data['code']['testCode']
                # Count occurrences of @Test annotation
                test_count = test_code.count('@Test')
                total_tests += test_count
                
            except Exception as e:
                logger.error(f"Error processing file {test_file}: {str(e)}")
                continue
                
        logger.info(f"Found {total_tests} tests in {total_files} files")
        return total_files, total_tests
        
    except Exception as e:
        logger.error(f"Error counting tests: {str(e)}")
        return 0, 0
