# AI-Powered White-Box Testing Module

## Overview
This module is part of a PhD research project on "Automatisiertes Testen mit KI" and implements LLM-based white-box testing for mobile applications. It generates unit tests through a two-phase architecture consisting of model training and operational test generation.

## Purpose
This module is responsible for:

- Extracting methods from Java and Kotlin code
- Generating unit tests using LocalAI and LLM
- Executing the generated tests using javac and kotlinc
- Saving and reporting test results

## Frontend Integration
The module integrates with the testing platform frontend to provide:
- Interactive code analysis and test generation
- Real-time test execution monitoring
- Coverage visualization
- Test result reporting and analysis
- Seamless workflow integration with other testing modules

## Key Features

### Training Phase
- Automated data collection and preprocessing from GitHub repositories
- Multi-stage quality filtering using LLM ensemble
- Synthetic data enrichment for improved test quality
- PEFT-based model fine-tuning with LoRA adapters
- Gradient checkpointing for efficient memory usage
- Systematic parameter optimization

### Operational Phase
1. **Code Analysis**
   - Method extraction from Java/Kotlin source
   - AST-based code analysis
   - Context extraction for method dependencies

2. **Test Generation**
   - Specialized prompt engineering strategies
   - Role-based prompting with Chain-of-Thought and Take-a-Step-Back
   - Support for both method-level and class-level testing
   - Automatic test improvement through iterative refinement

3. **Test Execution**
   - Maven/JUnit-based test execution
   - Real-time progress monitoring
   - Coverage analysis with JaCoCo
   - Detailed error analysis and reporting

## Architecture
## How it Works
1. The system extracts methods from Java or Kotlin classes
2. It generates prompts for each method, including method signature, body, and related information
3. The prompts are sent to LocalAI to generate unit tests
4. Generated tests are executed using javac or kotlinc
5. Test results are saved and displayed in the user interface

This module integrates with the frontend and other components to provide comprehensive white-box testing capabilities for mobile applications.


# To use the defects4j library

Install jdk 11 `apt-get update && apt-get install -y msopenjdk-11`

Change to java version `sudo update-alternatives --config java`

- `git clone https://github.com/rjust/defects4j`
- `cd defects4j`
- `cpanm --installdeps .`
- `./init.sh`

`export PATH=$PATH:/home/coder/workspace/defects4j/framework/bin`

- `apt install subversion`